@@ -65,7 +65,7 @@ str.emmGrid <- function(object, ...) {
             if (nm %in% object@roles$responses)
                 cat("multivariate response with means: ")
             else
-                cat("matrix with column means: ")
+                cat("matrix with column reference values: ")
             cat("\n        ")
             showlevs(object@matlevs[[nm]])
         }
@@ -202,8 +202,8 @@ vcov.emmGrid = function(object, ...) {
 #' along with \code{"adjust"} to determine appropriate adjustments to P values
 #' and confidence intervals.}
 #' 
-#' \item{\code{famSize}}{(integer) is the \code{nmeans} parameter for
-#' \code{\link{ptukey}} when \code{adjust="tukey"}. }
+#' \item{\code{famSize}}{(integer) is the number of means involved in a family of
+#' inferences; used in Tukey and Scheffe adjustments}
 #' 
 #' \item{\code{infer}}{(\code{logical} vector of length 2) is the default value
 #' of \code{infer} in \code{\link{summary.emmGrid}}.}
@@ -356,10 +356,10 @@ update.emmGrid = function(object, ..., silent = FALSE) {
 #'   for example, should we simplify a predictor name like \dQuote{\code{data$trt}}
 #'   to just \dQuote{\code{trt}}? Defaults to \code{TRUE}.}
 #' \item{\code{opt.digits}}{A logical value controlling the precision with which
-#'   summaries are printed. If \code{FALSE} (the default), the system value
-#'   \code{getOption("digits")} is used. If \code{TRUE}, the number of digits
+#'   summaries are printed. If \code{TRUE} (default), the number of digits
 #'   displayed is just enough to reasonably distinguish estimates from the ends
-#'   of their confidence intervals; but always at least 3 digits.}
+#'   of their confidence intervals; but always at least 3 digits. If
+#'   \code{FALSE}, the system value \code{getOption("digits")} is used.}
 #' }%%% end describe{}
 #' Some other options have more specific purposes:
 #' \describe{
@@ -446,7 +446,7 @@ emm_defaults = list (
     msg.nesting = TRUE,       # message when nesting is detected
     estble.tol = 1e-8,        # tolerance for estimability checks
     simplify.names = TRUE,    # simplify names like data$x to just "x"
-    opt.digits = FALSE,       # optimize displayed digits?
+    opt.digits = TRUE,        # optimize displayed digits?
     lmer.df = "kenward-roger",  # Use Kenward-Roger for df
     disable.pbkrtest = FALSE, # whether to bypass pbkrtest routines for lmerMod
     pbkrtest.limit = 3000,    # limit on N for enabling K-R
@@ -592,16 +592,18 @@ regrid = function(object, transform = c("response", "mu", "unlink", "log", "none
             object@misc$tran = object@misc$tran.mult = object@misc$inv.lbl = NULL
     }
     if (transform == "log") { # from prev block, we now have stuff on response scale
+        Vee = vcov(object)
         incl = which(object@bhat > 0)
-        if (length(incl) < length(object@bhat)) {
+        nas = which(is.na(object@bhat)) # already NA
+        negs = which(object@bhat <= 0)
+        if (length(negs) > 0) {
             message("Non-positive response predictions are flagged as non-estimable")
+            object@bhat[negs] = NA
             tmp = seq_along(object@bhat)
-            excl = tmp[-incl]
-            object@bhat[excl] = NA
-            object@nbasis = sapply(excl, function(ii) 0 + (tmp == ii))
+            object@nbasis = sapply(c(nas, negs), function(ii) 0 + (tmp == ii))
         }
         D = .diag(1/object@bhat[incl])
-        object@V = D %*% tcrossprod(object@V[incl, incl, drop = FALSE], D)
+        object@V = D %*% tcrossprod(Vee[incl, incl, drop = FALSE], D)
         object@bhat = log(object@bhat)
         if (!is.na(PB[1])) {
             PB[PB <= 0] = NA
